aboutsummaryrefslogtreecommitdiff
path: root/src/net_processing.h
diff options
context:
space:
mode:
authorSjors Provoost <sjors@sprovoost.nl>2021-12-10 20:12:05 +0700
committerSjors Provoost <sjors@sprovoost.nl>2021-12-24 16:29:04 +0100
commit923312fbf6a89efde1739da0b7209694d4f892ba (patch)
tree886d6d648912f5cd68ba6ffe400ec4d81945f643 /src/net_processing.h
parent34d5399211eeb61e7e7961c301fb2ddea8aa3f6a (diff)
downloadbitcoin-923312fbf6a89efde1739da0b7209694d4f892ba.tar.xz
rpc: use peer_id, block_hash for FetchBlock
Diffstat (limited to 'src/net_processing.h')
-rw-r--r--src/net_processing.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/net_processing.h b/src/net_processing.h
index 2c8ae05a26..c30ce056fa 100644
--- a/src/net_processing.h
+++ b/src/net_processing.h
@@ -45,11 +45,11 @@ public:
/**
* Attempt to manually fetch block from a given peer. We must already have the header.
*
* @param[in] id The peer id
* @param[in] block_index The blockindex
* @returns std::nullopt if a request was successfully made, otherwise an error message
*/
- virtual std::optional<std::string> FetchBlock(NodeId id, const CBlockIndex& block_index) = 0;
+ virtual std::optional<std::string> FetchBlock(NodeId peer_id, const CBlockIndex& block_index) = 0;
/** Begin running background tasks, should only be called once */
virtual void StartScheduledTasks(CScheduler& scheduler) = 0;
@@ -45,11 +45,11 @@ public:
* Attempt to manually fetch block from a given peer. We must already have the header.
*
- * @param[in] id The peer id
+ * @param[in] peer_id The peer id
* @param[in] block_index The blockindex
* @returns std::nullopt if a request was successfully made, otherwise an error message